pub struct BinaryU64Poly<const DEGREE_PLUS_ONE: usize>(/* private fields */);Implementations
Sourceimpl<const DEGREE_PLUS_ONE: usize> BinaryU64Poly<DEGREE_PLUS_ONE>
impl<const DEGREE_PLUS_ONE: usize> BinaryU64Poly<DEGREE_PLUS_ONE>
Sourceimpl<const DEGREE_PLUS_ONE: usize> BinaryU64Poly<DEGREE_PLUS_ONE>
impl<const DEGREE_PLUS_ONE: usize> BinaryU64Poly<DEGREE_PLUS_ONE>
Sourcepub fn new(coeffs: impl AsRef<[Boolean]>) -> Self
pub fn new(coeffs: impl AsRef<[Boolean]>) -> Self
Create a new polynomial with the given coefficients. If the input has fewer than N+1 coefficients, the remaining slots will be filled with zeros. If the input has more than N+1 coefficients, it will panic.
Sourcepub fn new_padded(coeffs: impl AsRef<[Boolean]>) -> Self
pub fn new_padded(coeffs: impl AsRef<[Boolean]>) -> Self
Create a new polynomial with the given coefficients. If the input has fewer than N+1 coefficients, the remaining slots will be filled with zeros. If the input has more than N+1 coefficients, it will panic.
Sourceimpl<const DEGREE_PLUS_ONE: usize> BinaryU64Poly<DEGREE_PLUS_ONE>
impl<const DEGREE_PLUS_ONE: usize> BinaryU64Poly<DEGREE_PLUS_ONE>
pub fn iter(&self) -> BinaryU64PolyIter<'_, DEGREE_PLUS_ONE> ⓘ